# Jupyter Notebook Server Shim

**A package that provides a simple transition away from Jupyter Notebook to Jupyter Server.**

The library provides a simple way for projects like JupyterLab and nteract_on_jupyter to transition from depending on jupyter/notebook to jupyter/jupyter_server for the core Jupyter Tornado Server.